@@ -244,6 +244,10 @@ class SymmathSBML(SymmathBase):
             substitute all species
         is_sub_others: bool
             substitute the non-species, non-parameters
+
+        Returns
+        -------
+        DataFrame
         """
         dct = self._getSubstitutionDct(
               is_sub_parameters=is_sub_parameters,
@@ -529,3 +533,55 @@ class SymmathSBML(SymmathBase):
         names = list(set(names))
         names.sort()
         return names
+     
+    def getJacobianSymbols(self, is_sub_parameters=True,
+          is_sub_species=False, is_sub_others=True,
+          is_format=True):
+        """
+        Substitutes into the Jacobian as directed. Provides
+        information about the symbols present in the Jacobian.
+   
+        Parameters
+        ----------
+        is_sub_parameters: bool
+            substitute all parameters
+        is_sub_species: bool
+            substitute all species
+        is_sub_others: bool
+            substitute the non-species, non-parameters
+        is_format: bool
+            print a formatted string
+
+        Returns
+        -------
+        dict
+            key: species name
+            value: Series
+                index: species (partial derivative)
+                value: expression containing symbols
+        """
+        jacobian = self.getJacobian(
+              is_sub_parameters=is_sub_parameters,
+              is_sub_species=is_sub_species,
+              is_sub_others=is_sub_others)
+        dct = {}
+        for species_row in jacobian.index:
+            species_dct = {}
+            for species_column in jacobian.columns:
+                entry = jacobian.loc[species_row, species_column]
+                if len(entry.free_symbols) > 0:
+                    species_dct[species_column] = entry
+            if len(species_dct) > 0:
+                dct[str(species_row)] = pd.Series(species_dct)
+        #
+        if is_format:
+            if len(dct) == 0:
+                print ("No symbols found")
+            else:
+                pd.set_option("max_colwidth", 300)
+                for name, ser in dct.items():
+                    print(" ")
+                    print("**%s**" % name)
+                    print(ser)
+        else:
+            return dct
